==> react-pagination-basic-1.6.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import React from 'react';
import PaginationItem from './sui-pagination-item';
var FIRST_PAGE = 1;
var PAGINATION_STEP = 1;

function PaginationBasic(_ref) {
  var createUrl = _ref.createUrl,
      currentPage = _ref.currentPage,
      factoryLink = _ref.factoryLink,
      handlePaginate = _ref.handlePaginate,
      patternUrl = _ref.patternUrl,
      totalPages = _ref.totalPages,
      props = _objectWithoutPropertiesLoose(_ref, ["createUrl", "currentPage", "factoryLink", "handlePaginate", "patternUrl", "totalPages"]);

  var renderPaginationItem = function renderPaginationItem(itemProps) {
    return React.createElement(PaginationItem, Object.assign({}, itemProps, {
      createUrl: createUrl,
      factoryLink: factoryLink,
      handlePaginate: handlePaginate,
      key: itemProps.pageNumber,
      patternUrl: patternUrl
    }));
  };

  var getPrevButton = function getPrevButton() {
    return renderPaginationItem({
      pageNumber: currentPage - PAGINATION_STEP,
      pageText: props.prevText,
      isControl: true
    });
  };

  var getNextButton = function getNextButton() {
    return renderPaginationItem({
      pageNumber: currentPage + PAGINATION_STEP,
      pageText: props.nextText,
      isControl: true
    });
  };

  var getFirstLastSeparator = function getFirstLastSeparator(key) {
    return React.createElement("li", {
      className: "sui-PaginationBasic-item sui-PaginationBasic-item--separator",
      key: key
    }, props.firstLastSeparatorText);
  };

  var getPaginationItems = function getPaginationItems() {
    var leftWindow = currentPage - props.window;
    var rightWindow = currentPage + props.window;
    var min = leftWindow < FIRST_PAGE ? FIRST_PAGE : leftWindow;
    var max = rightWindow > totalPages ? totalPages : rightWindow;
    var paginationItems = [];

    if (props.showFirstLast && min > FIRST_PAGE) {
      paginationItems.push(renderPaginationItem({
        pageNumber: FIRST_PAGE,
        pageText: FIRST_PAGE
      }));
      paginationItems.push(getFirstLastSeparator('firstSeparator'));
    }

    for (var i = min; i <= max; i++) {
      var paginationItem = renderPaginationItem({
        pageNumber: i,
        pageText: i,
        isCurrent: i === currentPage
      });
      paginationItems.push(paginationItem);
    }

    if (props.showFirstLast && max < totalPages) {
      paginationItems.push(getFirstLastSeparator('lastSeparator'));
      paginationItems.push(renderPaginationItem({
        pageNumber: totalPages,
        pageText: totalPages
      }));
    }

    return paginationItems;
  };

  var showPrevButton = currentPage > FIRST_PAGE;
  var showNextButton = currentPage < totalPages;
  return React.createElement("div", {
    className: "sui-PaginationBasic"
  }, React.createElement("ul", {
    className: "sui-PaginationBasic-list"
  }, showPrevButton && getPrevButton(), getPaginationItems(), showNextButton && getNextButton()));
}

PaginationBasic.defaultProps = {
  firstLastSeparatorText: '...',
  handlePaginate: function handlePaginate() {},
  nextText: 'Next',
  prevText: 'Prev'
};
PaginationBasic.displayName = 'PaginationBasic';
export default PaginationBasic;

==> react-pagination-basic-1.8.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { createElement as _createElement } from "react";
import PaginationItem from './sui-pagination-item';
var FIRST_PAGE = 1;
var PAGINATION_STEP = 1;

function PaginationBasic(_ref) {
  var createUrl = _ref.createUrl,
      currentPage = _ref.currentPage,
      factoryLink = _ref.factoryLink,
      handlePaginate = _ref.handlePaginate,
      patternUrl = _ref.patternUrl,
      totalPages = _ref.totalPages,
      props = _objectWithoutPropertiesLoose(_ref, ["createUrl", "currentPage", "factoryLink", "handlePaginate", "patternUrl", "totalPages"]);

  var renderPaginationItem = function renderPaginationItem(itemProps) {
    return /*#__PURE__*/_createElement(PaginationItem, _extends({}, itemProps, {
      createUrl: createUrl,
      factoryLink: factoryLink,
      handlePaginate: handlePaginate,
      key: itemProps.pageNumber,
      patternUrl: patternUrl
    }));
  };

  var getPrevButton = function getPrevButton() {
    return renderPaginationItem({
      pageNumber: currentPage - PAGINATION_STEP,
      pageText: props.prevText,
      isControl: true
    });
  };

  var getNextButton = function getNextButton() {
    return renderPaginationItem({
      pageNumber: currentPage + PAGINATION_STEP,
      pageText: props.nextText,
      isControl: true
    });
  };

  var getFirstLastSeparator = function getFirstLastSeparator(key) {
    return /*#__PURE__*/_jsx("li", {
      className: "sui-PaginationBasic-item sui-PaginationBasic-item--separator",
      children: props.firstLastSeparatorText
    }, key);
  };

  var getPaginationItems = function getPaginationItems() {
    var leftWindow = currentPage - props.window;
    var rightWindow = currentPage + props.window;
    var min = leftWindow < FIRST_PAGE ? FIRST_PAGE : leftWindow;
    var max = rightWindow > totalPages ? totalPages : rightWindow;
    var paginationItems = [];

    if (props.showFirstLast && min > FIRST_PAGE) {
      paginationItems.push(renderPaginationItem({
        pageNumber: FIRST_PAGE,
        pageText: FIRST_PAGE
      }));
      paginationItems.push(getFirstLastSeparator('firstSeparator'));
    }

    for (var i = min; i <= max; i++) {
      var paginationItem = renderPaginationItem({
        pageNumber: i,
        pageText: i,
        isCurrent: i === currentPage
      });
      paginationItems.push(paginationItem);
    }

    if (props.showFirstLast && max < totalPages) {
      paginationItems.push(getFirstLastSeparator('lastSeparator'));
      paginationItems.push(renderPaginationItem({
        pageNumber: totalPages,
        pageText: totalPages
      }));
    }

    return paginationItems;
  };

  var showPrevButton = currentPage > FIRST_PAGE;
  var showNextButton = currentPage < totalPages;
  return /*#__PURE__*/_jsx("div", {
    className: "sui-PaginationBasic",
    children: /*#__PURE__*/_jsxs("ul", {
      className: "sui-PaginationBasic-list",
      children: [showPrevButton && getPrevButton(), getPaginationItems(), showNextButton && getNextButton()]
    })
  });
}

PaginationBasic.defaultProps = {
  firstLastSeparatorText: '...',
  handlePaginate: function handlePaginate() {},
  nextText: 'Next',
  prevText: 'Prev'
};
PaginationBasic.displayName = 'PaginationBasic';
export default PaginationBasic;
